@@ -6,7 +6,8 @@ from .. import Provider as LoremProvider
 
 class Provider(LoremProvider):
     """en_US word list is drawn from Education First's "1000 Most Common Words in English":
-    http://www.ef.edu/english-resources/english-vocabulary/top-1000-words/ """
+    http://www.ef.edu/english-resources/english-vocabulary/top-1000-words/
+    Some words have been removed to make this list appropriate for public testing"""
 
     word_list = (
         'a',
@@ -135,7 +136,6 @@ class Provider(LoremProvider):
         'camera',
         'campaign',
         'can',
-        'cancer',
         'candidate',
         'capital',
         'car',
@@ -176,7 +176,6 @@ class Provider(LoremProvider):
         'collection',
         'college',
         'color',
-        'come',
         'commercial',
         'common',
         'community',
@@ -211,9 +210,7 @@ class Provider(LoremProvider):
         'data',
         'daughter',
         'day',
-        'dead',
         'deal',
-        'death',
         'debate',
         'decade',
         'decide',
@@ -230,7 +227,6 @@ class Provider(LoremProvider):
         'determine',
         'develop',
         'development',
-        'die',
         'difference',
         'different',
         'difficult',
@@ -240,7 +236,6 @@ class Provider(LoremProvider):
         'discover',
         'discuss',
         'discussion',
-        'disease',
         'do',
         'doctor',
         'dog',
@@ -299,7 +294,6 @@ class Provider(LoremProvider):
         'face',
         'fact',
         'factor',
-        'fail',
         'fall',
         'family',
         'far',
@@ -320,7 +314,6 @@ class Provider(LoremProvider):
         'financial',
         'find',
         'fine',
-        'finger',
         'finish',
         'fire',
         'firm',
@@ -373,7 +366,6 @@ class Provider(LoremProvider):
         'hair',
         'half',
         'hand',
-        'hang',
         'happen',
         'happy',
         'hard',
@@ -383,7 +375,6 @@ class Provider(LoremProvider):
         'health',
         'hear',
         'heart',
-        'heat',
         'heavy',
         'help',
         'her',
@@ -448,7 +439,6 @@ class Provider(LoremProvider):
         'keep',
         'key',
         'kid',
-        'kill',
         'kind',
         'kitchen',
         'know',
@@ -470,12 +460,10 @@ class Provider(LoremProvider):
         'leave',
         'left',
         'leg',
-        'legal',
         'less',
         'let',
         'letter',
         'level',
-        'lie',
         'life',
         'light',
         'like',
@@ -491,7 +479,6 @@ class Provider(LoremProvider):
         'lose',
         'loss',
         'lot',
-        'love',
         'low',
         'machine',
         'magazine',
@@ -586,7 +573,6 @@ class Provider(LoremProvider):
         'officer',
         'official',
         'often',
-        'oh',
         'oil',
         'ok',
         'old',
@@ -611,7 +597,6 @@ class Provider(LoremProvider):
         'own',
         'owner',
         'page',
-        'pain',
         'painting',
         'paper',
         'parent',
@@ -623,7 +608,6 @@ class Provider(LoremProvider):
         'party',
         'pass',
         'past',
-        'patient',
         'pattern',
         'pay',
         'peace',
@@ -632,7 +616,6 @@ class Provider(LoremProvider):
         'perform',
         'performance',
         'perhaps',
-        'period',
         'person',
         'personal',
         'phone',
@@ -666,9 +649,7 @@ class Provider(LoremProvider):
         'pretty',
         'prevent',
         'price',
-        'private',
         'probably',
-        'problem',
         'process',
         'produce',
         'product',
@@ -718,7 +699,6 @@ class Provider(LoremProvider):
         'religious',
         'remain',
         'remember',
-        'remove',
         'report',
         'represent',
         'Republican',
@@ -771,14 +751,10 @@ class Provider(LoremProvider):
         'set',
         'seven',
         'several',
-        'sex',
-        'sexual',
         'shake',
         'share',
         'she',
-        'shoot',
         'short',
-        'shot',
         'should',
         'shoulder',
         'show',
@@ -943,9 +919,7 @@ class Provider(LoremProvider):
         'value',
         'various',
         'very',
-        'victim',
         'view',
-        'violence',
         'visit',
         'voice',
         'vote',
@@ -958,7 +932,6 @@ class Provider(LoremProvider):
         'water',
         'way',
         'we',
-        'weapon',
         'wear',
         'week',
         'weight',
