@@ -128,7 +128,7 @@ class Provider(PersonProvider):
         "ศุภจัตุรัส", "โชติเลอศักดิ์", "บุณยะโหตระ", "กสานติกุล", "ลิ้มพงศานุรักษ์",
         "อนุราษฎร์", "จิตต์มิตรภาพ", "สุวรรณเวลา", "สิทธีอมร", "อ่องจริต", "ดุสิตสิน",
         "ภานุภาค", "ฟูตระกูล", "โปษยะจินดา", "สิตปรีชา", "ช่วงโชติ", "ศรีจิตรา", "ประมวล",
-        "บุญเชียร", "หงศ์ลดารมภ์", "รามสูต", "อึ้งถาวร", "วาทีสาธกกิจ", "สันติไชยกุล",)
+        "บุญเชียร", "หงศ์ลดารมภ์", "รามสูต", "อึ้งถาวร", "วาทีสาธกกิจ", "สันติไชยกุล")
 
     # last name that has given by senior officer
     # http://www.reurnthai.com/index.php?topic=5273.45
@@ -163,14 +163,29 @@ class Provider(PersonProvider):
         "นิยมสำหรวจ",
         "นกทอง", "นุชแนวนุ่ม", "นาคสุทิน", "นพคเชนทร์", "นาคะนคร", "นิละทัต", "นาควงษ์",
         "นากกนก", "บุนยาภิสนท์", "บุญญาภิรมย์", "บุณยะภาชน์", "บินดี", "บุนยะศัพท์",
-        "บุนยะตีรณะ", "บุญญาไลย์", "บุญบำรุง",)
+        "บุนยะตีรณะ", "บุญญาไลย์", "บุญบำรุง")
 
     # thai suffix that has given by the king
     # https://th.wikipedia.org/wiki/%E0%B8%99%E0%B8%B2%E0%B8%A1%E0%B8%AA%E0%B8%81%E0%B8%B8%E0%B8%A5%E0%B8%9E%E0%B8%A3%E0%B8%B0%E0%B8%A3%E0%B8%B2%E0%B8%8A%E0%B8%97%E0%B8%B2%E0%B8%99
     suffixes = (
-        "ณ กาฬสินธุ์", "ณ จัมปาศักดิ์", "ณ เชียงใหม่", "ณ ตะกั่วทุ่ง", "ณ ถลาง", "ณ นคร",
-        "ณ น่าน", "ณ บางช้าง", "ณ ป้อมเพชร์", "ณ พัทลุง", "ณ พิศณุโลก", "ณ มโนรม",
+        "ณ กาฬสินธุ์",
+        "ณ จัมปาศักดิ์",
+        "ณ เชียงใหม่",
+        "ณ ตะกั่วทุ่ง",
+        "ณ ถลาง",
+        "ณ นคร",
+        "ณ น่าน",
+        "ณ บางช้าง",
+        "ณ ป้อมเพชร์",
+        "ณ พัทลุง",
+        "ณ พิศณุโลก",
+        "ณ มโนรม",
         "ณ มหาไชย",
-        "ณ ร้อยเอ็จ", "ณ ระนอง", "ณ ลำปาง", "ณ ลำพูน", "ณ วิเชียร", "ณ สงขลา",
+        "ณ ร้อยเอ็จ",
+        "ณ ระนอง",
+        "ณ ลำปาง",
+        "ณ ลำพูน",
+        "ณ วิเชียร",
+        "ณ สงขลา",
         "ณ หนองคาย",
         "ณ อุบล")
