@@ -29,5 +29,5 @@ class Provider(PhoneNumberProvider):
         '017-###-####',
         '018-###-####',
         '019-###-####',
-        '070-####-####'
+        '070-####-####',
     )
